@@ -28,7 +28,7 @@
 #include "../src/getconfigoperation.h"
 #include "../src/backendmanager_p.h"
 
-Q_LOGGING_CATEGORY(KSCREEN_QSCREEN, "kscreen.qscreen");
+Q_LOGGING_CATEGORY(KSCREEN_QSCREEN, "kscreen.qscreen")
 
 using namespace KScreen;
 
@@ -42,6 +42,7 @@ private Q_SLOTS:
     void verifyScreen();
     void verifyOutputs();
     void verifyModes();
+    void verifyFeatures();
     void commonUsagePattern();
     void cleanupTestCase();
 
@@ -127,7 +128,12 @@ void testQScreenBackend::verifyOutputs()
         QVERIFY(output->isEnabled());
         QVERIFY(output->geometry() != QRectF(1,1,1,1));
         QVERIFY(output->geometry() != QRectF());
-        QVERIFY(output->sizeMm() != QSize());
+
+        // Pass, but leave a note, when the x server doesn't report physical size
+        if (!output->sizeMm().isValid()) {
+            QEXPECT_FAIL("", "The X server doesn't return a sensible physical output size", Continue);
+            QVERIFY(output->sizeMm() != QSize());
+        }
         QVERIFY(output->edid() != 0);
         QCOMPARE(output->rotation(), Output::None);
         QVERIFY(!ids.contains(output->id()));
@@ -204,6 +210,15 @@ void testQScreenBackend::cleanupTestCase()
     qApp->exit(0);
 }
 
+void testQScreenBackend::verifyFeatures()
+{
+    GetConfigOperation *op = new GetConfigOperation();
+    op->exec();
+    auto config = op->config();
+    QVERIFY(config->supportedFeatures().testFlag(Config::Feature::None));
+    QVERIFY(!config->supportedFeatures().testFlag(Config::Feature::Writable));
+    QVERIFY(!config->supportedFeatures().testFlag(Config::Feature::PrimaryDisplay));
+}
 
 
 QTEST_MAIN(testQScreenBackend)
